'use client'

import { useState, useEffect } from 'react'
import { FiEdit2, FiTrash2, FiPlus, FiGrid, FiClock } from 'react-icons/fi'
import DashboardLayout from '@/components/layout/DashboardLayout'
import Link from 'next/link'
import { tableService } from '@/services/api'
import { useUser } from '@/contexts/UserContext'
import { getStatusColor, getStatusText, TableStatus, getDate } from '@/config/tableConfig'

interface Table {
  id: number
  name: string
  status: TableStatus
  created_at: string
  date: string
}

export default function TablesPage() {
  const { user } = useUser()
  const [tables, setTables] = useState<Table[]>([])
  const [loading, setLoading] = useState(true)
  const [error, setError] = useState<string | null>(null)

  const fetchTables = async () => {
    try {
      setLoading(true)
      const response = await tableService.index(user?.token || '')
      console.log(response.data.tables)
      setTables(response.data.tables || [])
    } catch (error) {
      console.error('Masa listesi yüklenirken hata:', error)
      setError('Masalar yüklenirken bir hata oluştu')
    } finally {
      setLoading(false)
    }
  }

  const handleDelete = async (id: number) => {
    try {
      const response = await tableService.destroy(id.toString(), user?.token || '')
      console.log(response.data)
      fetchTables()
    } catch (error) {
      console.error('Masa silinirken hata:', error)
      setError('Masa silinirken bir hata oluştu')
    }
  }

  useEffect(() => {
    if (user?.token) {
      fetchTables()
    }
  }, [user?.token])

  if (loading) {
    return (
      <DashboardLayout>
        <div className="w-full mx-auto">
          <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl p-6">
            <div className="animate-pulse text-center text-slate-500 dark:text-slate-400">
              Yükleniyor...
            </div>
          </div>
        </div>
      </DashboardLayout>
    )
  }

  if (error) {
    return (
      <DashboardLayout>
        <div className="w-full mx-auto">
          <div className="bg-red-50 dark:bg-red-900/50 backdrop-blur-sm rounded-3xl p-6">
            <div className="text-center text-red-500 dark:text-red-400">
              {error}
            </div>
          </div>
        </div>
      </DashboardLayout>
    )
  }

  

  return (
    <DashboardLayout>
      <div className="space-y-6">
        {/* Başlık ve Yeni Ekle Butonu */}
        <div className="flex flex-col sm:flex-row sm:items-center justify-between gap-4">
          <div>
            <h1 className="text-2xl font-bold text-slate-800 dark:text-white">
              Masa Listesi
            </h1>
            <p className="mt-1 text-sm text-slate-500 dark:text-slate-400">
              Tüm masaları görüntüle, düzenle ve yönet
            </p>
          </div>
          <Link
            href="/dashboard/tables/add"
            className="inline-flex items-center gap-2 px-4 py-2.5 text-sm font-medium 
                     text-white bg-gradient-to-r from-fuchsia-500 to-purple-600 
                     rounded-xl hover:opacity-90 transition-all shadow-lg shadow-fuchsia-500/25"
          >
            <FiPlus className="w-4 h-4" />
            Yeni Masa Ekle
          </Link>
        </div>

        {/* Masa Listesi */}
        <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm rounded-3xl shadow-lg border border-slate-200/50 dark:border-slate-700/50">
          <div className="overflow-x-auto">
            <table className="w-full">
              <thead>
                <tr className="border-b border-slate-200/50 dark:border-slate-700/50">
                  <th className="text-left text-xs font-medium text-slate-500 dark:text-slate-400 uppercase tracking-wider px-6 py-4">
                    Masa Adı
                  </th>
                  <th className="text-left text-xs font-medium text-slate-500 dark:text-slate-400 uppercase tracking-wider px-6 py-4">
                    Durum
                  </th>
                  <th className="text-left text-xs font-medium text-slate-500 dark:text-slate-400 uppercase tracking-wider px-6 py-4 hidden sm:table-cell">
                    Oluşturulma
                  </th>
                  <th className="text-left text-xs font-medium text-slate-500 dark:text-slate-400 uppercase tracking-wider px-6 py-4 hidden lg:table-cell">
                    Son Sipariş
                  </th>
                  <th className="text-right text-xs font-medium text-slate-500 dark:text-slate-400 uppercase tracking-wider px-6 py-4">
                    İşlemler
                  </th>
                </tr>
              </thead>
              <tbody className="divide-y divide-slate-200/50 dark:divide-slate-700/50">
                {Array.isArray(tables) && tables.map((table: Table) => (
                  <tr
                    key={table.id}
                    className="hover:bg-slate-50/50 dark:hover:bg-slate-700/50 transition-colors"
                  >
                    <td className="px-6 py-4 whitespace-nowrap">
                      <div className="flex items-center gap-3">
                        <div className="w-10 h-10 rounded-lg bg-gradient-to-r from-fuchsia-500 to-purple-600 
                                    flex items-center justify-center shadow-lg">
                          <FiGrid className="w-5 h-5 text-white" />
                        </div>
                        <span className="text-sm font-medium text-slate-700 dark:text-slate-200">
                          {table.name}
                        </span>
                      </div>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap">
                      <span className={`inline-flex items-center px-3 py-1 rounded-full text-xs font-medium ${getStatusColor(table.status)}`}>
                        {getStatusText(table.status)}
                      </span>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap hidden sm:table-cell">
                      <span className="text-sm text-slate-500 dark:text-slate-400">
                        {getDate(table.created_at)}
                      </span>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap hidden lg:table-cell">
                      <div className="flex items-center gap-1.5">
                        <FiClock className="w-4 h-4 text-slate-400" />
                        <span className="text-sm text-slate-500 dark:text-slate-400">
                          {table.date ? getDate(table.date) : 'Sipariş Eklenmedi'}
                        </span>
                      </div>
                    </td>
                    <td className="px-6 py-4 whitespace-nowrap text-right">
                      <div className="flex items-center justify-end gap-2">
                        <Link
                          href={`/dashboard/tables/edit/${table.id}`}
                          className="p-2 rounded-lg bg-slate-100/50 dark:bg-slate-700/50 
                                   text-slate-600 dark:text-slate-300 
                                   hover:bg-fuchsia-50 dark:hover:bg-slate-600/50 
                                   hover:text-fuchsia-500 transition-colors"
                        >
                          <FiEdit2 className="w-4 h-4" />
                        </Link>
                        <button
                          onClick={() => handleDelete(table.id)}
                          className="p-2 rounded-lg bg-slate-100/50 dark:bg-slate-700/50 
                                   text-slate-600 dark:text-slate-300 
                                   hover:bg-red-50 dark:hover:bg-red-900/10 
                                   hover:text-red-500 transition-colors"
                        >
                          <FiTrash2 className="w-4 h-4" />
                        </button>
                      </div>
                    </td>
                  </tr>
                ))}
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </DashboardLayout>
  )
} 